ConsoleObject class

Console object implementation

Constructors

ConsoleObject()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createConsoleObject() JSObject
Create console object with all its methods
error(List<JSValue> args) JSValue
console.error() - to stderr
log(List<JSValue> args) JSValue
warn(List<JSValue> args) JSValue
console.warn() - warning