ExportAllDeclaration class

Export all exports of a module (export * from 'module')

Inheritance

Constructors

ExportAllDeclaration({required LiteralExpression source, Expression? exported, required int line, required int column})
const

Properties

column int
finalinherited
exported Expression?
final
hashCode int
The hash code for this object.
no setterinherited
line int
Position in the source code
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source LiteralExpression
final

Methods

accept<T>(ASTVisitor<T> visitor) → T
Methode pour le visitor pattern
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited