JSString class

String value

Inheritance
Available extensions

Constructors

JSString(String value)

Properties

asRegExp JSRegExp

Available on JSValue, provided by the JSValueRegExpExtension extension

Cast to JSRegExp (throws an error if it's not a RegExp)
no setter
hashCode int
The hash code for this object.
no setterinherited
isBigInt bool
no setterinherited
isBoolean bool
no setterinherited
isFalsy bool
Check if value is "falsy"
no setterinherited
isFunction bool
no setterinherited
isNull bool
no setterinherited
isNumber bool
no setterinherited
isObject bool
no setterinherited
isPrimitive bool
Check if value is "primitive" (non-object)
no setterinherited
isRegExp bool

Available on JSValue, provided by the JSValueRegExpExtension extension

Check if this value is a RegExp
no setter
isString bool
no setterinherited
isSymbol bool
no setterinherited
isTruthy bool
Check if value is "truthy"
no setterinherited
isUndefined bool
Type checks
no setterinherited
primitiveValue → dynamic
Get the underlying primitive value
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type JSValueType
no setteroverride
value String
final

Methods

equals(JSValue other) bool
Comparison operations
override
getIterator() JSStringIterator
String iteration support for primitive strings
getIterator() JSStringIterator

Available on JSString, provided by the JSStringIterableExtension extension

Support iteration for primitive strings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
strictEquals(JSValue other) bool
override
toBoolean() bool
JavaScript type conversions (coercion)
override
toNumber() double
override
toObject() JSObject
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited