JSSymbolConstructor class

Symbol constructor for JavaScript

Inheritance
Implemented types
Available extensions

Constructors

JSSymbolConstructor()

Properties

asRegExp JSRegExp

Available on JSValue, provided by the JSValueRegExpExtension extension

Cast to JSRegExp (throws an error if it's not a RegExp)
no setter
closureEnvironment → dynamic
finalinherited
declaration → dynamic
finalinherited
functionName String
Get the function's name
no setterinherited
functionName String

Available on JSFunction, provided by the FunctionExtensions extension

Gets the function name
no setter
hashCode int
The hash code for this object.
no setterinherited
isArrowFunction bool
finalinherited
isBigInt bool
no setterinherited
isBoolean bool
no setterinherited
isConstructor bool
Check if this function can be used as a constructor Arrow functions cannot be used as constructors Regular functions and class constructors can be
no setterinherited
isFalsy bool
Check if value is "falsy"
no setterinherited
isFunction bool
no setterinherited
isMethodDefinition bool
finalinherited
isNull bool
no setterinherited
isNumber bool
no setterinherited
isObject bool
no setterinherited
isPrimitive bool
Check if value is "primitive" (non-object)
no setterinherited
isRegExp bool

Available on JSValue, provided by the JSValueRegExpExtension extension

Check if this value is a RegExp
no setter
isString bool
no setterinherited
isSymbol bool
no setterinherited
isTruthy bool
Check if value is "truthy"
no setterinherited
isUndefined bool
Type checks
no setterinherited
moduleUrl String?
getter/setter pairinherited
parameterCount int
Nombre de parametres de la fonction Per ES spec: function.length is the count of parameters before the first one with a default value or a rest parameter
no setterinherited
parameterCount int

Available on JSFunction, provided by the FunctionExtensions extension

Gets the number of parameters
no setter
parentClass JSClass?
getter/setter pairinherited
primitiveValue → dynamic
Get the underlying primitive value
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceText String?
getter/setter pairinherited
strictMode bool
finalinherited
type JSValueType
no setterinherited

Methods

callWithRuntime(List<JSValue> args, JSValue thisBinding, JSRuntime runtime) JSValue
override
containsOwnProperty(String name) bool
Check if this function has an own property with the given name
inherited
defineOwnProperty(String name, PropertyDescriptor descriptor) → void
Set a property descriptor for a function property This allows setting the writable, enumerable, and configurable flags
inherited
defineProperty(String name, PropertyDescriptor descriptor) → void
Define a property with a complete descriptor (Object.defineProperty)
inherited
deleteProperty(String name) bool
Delete a property from this function (ES5 [Delete])
inherited
equals(JSValue other) bool
Comparison operations
inherited
getInternalSlot(String name) → dynamic
Get an internal slot value
inherited
getOwnPropertyDescriptor(String name) PropertyDescriptor?
Obtient le descripteur de properte pour a property donnee
inherited
getProperty(String name) JSValue
inherited
getPropertyNames({bool enumerableOnly = false}) List<String>
Get all own property names (excluding symbol keys)
inherited
getSymbolKeys() Iterable<JSSymbol>
Get all symbol keys tracked on this function
inherited
hasInternalSlot(String name) bool
Check if an internal slot exists
inherited
hasProperty(String name) bool
inherited
initialize() → void
Initialize Symbol constructor properties and methods
keyForMethod(List<JSValue> args) JSValue
Symbol.keyFor(symbol)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerSymbolKey(String propertyKey, JSSymbol symbol) → void
Register a symbol key for tracking
inherited
removeOwnProperty(String name) bool
Remove a property from this function's own properties
inherited
setFunctionName(String newName) → void
Set the name of an anonymous function (used when assigned to a variable) This follows ES6 SetFunctionName abstract operation
inherited
setInternalSlot(String name, dynamic value) → void
Set an internal slot value
inherited
setProperty(String name, JSValue value) → void
inherited
strictEquals(JSValue other) bool
inherited
symbolForMethod(List<JSValue> args) JSValue
Symbol.for(key)
toBoolean() bool
JavaScript type conversions (coercion)
inherited
toNumber() double
inherited
toObject() JSObject
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited