SequenceExpression class
Sequence expression: (expr1, expr2, expr3)
- Inheritance
-
- Object
- ASTNode
- Expression
- SequenceExpression
Constructors
-
SequenceExpression({required List<
Expression> expressions, required int line, required int column}) -
const
Properties
- column → int
-
finalinherited
-
expressions
→ List<
Expression> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- line → int
-
Position in the source code
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept<
T> (ASTVisitor< T> visitor) → T -
Methode pour le visitor pattern
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited