SwitchStatement class

Switch statement

Inheritance

Constructors

SwitchStatement({required Expression discriminant, required List<SwitchCase> cases, required int line, required int column})
const

Properties

cases List<SwitchCase>
final
column int
finalinherited
discriminant Expression
final
hashCode int
The hash code for this object.
no setterinherited
line int
Position in the source code
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept<T>(ASTVisitor<T> visitor) → T
Methode pour le visitor pattern
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited