TokenUtils class

Utilities for tokens

Constructors

TokenUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getDisplayName(TokenType type) String
Returns the display name of a token type
getOperatorPrecedence(TokenType type) int
Returns the precedence of an operator (higher = more priority)
isRightAssociative(TokenType type) bool
Checks if an operator is right associative