ExecutionStack class
JavaScript execution stack
Constructors
Properties
-
contexts
→ List<
ExecutionContext> -
Access all contexts of the stack (for inspection)
no setter
- current → ExecutionContext
-
Current context
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Check if the stack is empty
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Stack size
no setter
Methods
-
currentStrictMode(
) → bool - Check if we are in strict mode
-
getStackTrace(
) → List< String> - Stack trace for debugging
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop(
) → ExecutionContext - Pop the current context
-
push(
ExecutionContext context) → void - Push a new context
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited