ObjectExpression class
Object literal expression ({a: 1, b: 2, ...other})
- Inheritance
-
- Object
- ASTNode
- Expression
- ObjectExpression
Constructors
- ObjectExpression({required List properties, bool hasTrailingComma = false, required int line, required int column})
-
const
Properties
- column → int
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasTrailingComma → bool
-
final
- line → int
-
Position in the source code
finalinherited
- properties → List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept<
T> (ASTVisitor< T> visitor) → T -
Methode pour le visitor pattern
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited