RuntimeCallableFunction class abstract
Specialized function objects that can execute directly on any runtime.
This lets the VM call selected legacy JSFunction subclasses without going through the generic evaluator bridge.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
callWithRuntime(
List< JSValue> args, JSValue thisBinding, JSRuntime runtime) → JSValue -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited